local config = require("config")

local function choose_team(player)
  if player.gui.screen.choose_team then
    player.gui.screen.choose_team.destroy()
  end
  local frame = player.gui.screen.add{
    name="choose_team",
    type="frame",
    caption="Pick your team",
    direction="vertical",
    style="dark_frame"
  }
  frame.auto_center = true

  add_team_option(player, frame, "north")
  add_team_option(player, frame, "south")

end

function add_team_option(player, parent, team_name)
  local frame = parent.add{
    type="frame"
  }

  frame.add{
    type="minimap",
    position=game.forces[team_name].get_spawn_position(player.surface),
    zoom=0.9,
    style="minimap"
  }

  local player_list = frame.add{
    type="frame",
    caption="Players"
  }

  for _, player in pairs(game.forces[team_name].connected_players) do
    player_list.add{
      type="label",
      caption=player.name
    }
  end

  frame.add{
    name=team_name.."_button",
    type="button",
    caption="Join "..team_name
  }
end

local function on_gui_click(event, join_team)
  if not (event and event.element and event.element.valid) then return end
  local player = game.players[event.player_index]
  if not (player.gui.screen.choose_team) then return end
  local element_name = event.element.name
  local force_name = nil
  if element_name == "south_button" then force_name = "south" end
  if element_name == "north_button" then force_name = "north" end
  if not(force_name) then return end

  join_team(player, force_name)
  player.gui.screen.choose_team.destroy()
end

local teams_gui = {}

teams_gui.choose_team = choose_team
teams_gui.on_gui_click = on_gui_click

return teams_gui
