local config = require("config")
local gui = require("teams-gui")
local math2d = require("math2d")

local function on_init()
  local spawn_position = config.teams.spawn
  create_team("north", {x=spawn_position.x, y=-spawn_position.y})
  create_team("south", {x=spawn_position.x, y=spawn_position.y})

  local south_force = game.forces.south
  local north_force = game.forces.north
  south_force.set_cease_fire(north_force, true)
  north_force.set_cease_fire(south_force, true)
end

function create_team(team_name, spawn_position)
  local force = game.create_force(team_name)

  force.set_spawn_position(spawn_position, "nauvis")
  -- force.chart(game.surfaces.nauvis, math2d.bounding_box.create_from_centre(spawn_position, 128, 128))
  -- local surface = game.surfaces.nauvis
  -- surface.request_to_generate_chunks({x=spawn_position.x/32,y=spawn_position.y/32}, config.map.team_ribbon_chunk_width)
  -- surface.force_generate_chunk_requests()

  -- force.chart_all(game.surfaces.nauvis)

  force.set_friend("player", true)
  force.share_chart = true
  force.research_queue_enabled = true
  force.technologies["artillery"].enabled = false
  force.technologies["artillery-shell-range-1"].enabled = false
  force.technologies["artillery-shell-speed-1"].enabled = false
end


local function on_player_created(event)
end


local function on_player_joined_game(event)
  local player = game.get_player(event.player_index)
  local surface = game.surfaces.nauvis

  if player.online_time == 0 or player.force.name == "player" then
    make_spectator(player)
  end
  
end

function make_spectator(player)
  player.force = "player"
  if (player.character) then player.character.destroy() end
  player.set_controller({type=defines.controllers.spectator})
  player.teleport({x=0,y=0}, game.surfaces.nauvis)
  gui.choose_team(player)
end

local function join_team(player, team_name)
  local surface = game.surfaces.nauvis

  player.force = team_name
  player.teleport(surface.find_non_colliding_position("character", player.force.get_spawn_position(surface), 0, 0.5), surface)
  if not(player.character) then
    player.set_controller({type=defines.controllers.god})
    player.create_character()
  end
  
end

local function add_remote_interface()
  remote.add_interface("teams", {
    join = join_team,
    spectate = make_spectator
  })
end

local function on_gui_click(event)
  gui.on_gui_click(event, join_team)
end

local function chart_visibility(event)
  local south_force = game.forces.south
  local north_force = game.forces.north
  chart_force(south_force, north_force)
  chart_force(north_force, south_force)
end

function chart_force(force, other)
  local surface = game.surfaces.nauvis
  local d = 32*3
  for _, player in pairs(other.connected_players) do
    force.chart(surface, {{player.position.x - d, player.position.y - d}, {player.position.x + d, player.position.y + d}})
  end
end

local teams = {}

teams.on_init = on_init

teams.events =
{
  [defines.events.on_player_created] = on_player_created,
  [defines.events.on_player_joined_game] = on_player_joined_game
}

teams.on_nth_tick = {
  [60*10] = chart_visibility
}

teams.add_remote_interface = add_remote_interface

local teams_gui = {}
teams_gui.events =
{
  [defines.events.on_gui_click] = on_gui_click,
}


return {
  teams=teams,
  teams_gui=teams_gui
}
